@@ -4,10 +4,11 @@ use base qw(Plack::Component::Tags::HTML);
 use strict;
 use warnings;
 
-use Plack::Util::Accessor qw(generator image_link search_method search_title search_url title);
+use Plack::Util::Accessor qw(generator image_height image_link search_method
+	search_placeholder search_title search_url title);
 use Tags::HTML::Container;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub _prepare_app {
 	my $self = shift;
@@ -58,6 +59,9 @@ sub _css {
 			['d', 'margin-bottom', '20px'],
 			['d', 'margin-left', 'auto'],
 			['d', 'margin-right', 'auto'],
+			defined $self->image_height ? (
+				['d', 'height', $self->image_height],
+			) : (),
 			['e'],
 		);
 	}
@@ -111,6 +115,9 @@ sub _tags_middle {
 				['b', 'input'],
 				['a', 'type', 'text'],
 				['a', 'autofocus', 'autofocus'],
+				defined $self->search_placeholder ? (
+					['a', 'placeholder', $self->search_placeholder],
+				) : (),
 				['e', 'input'],
 				['b', 'button'],
 				['a', 'type', 'submit'],
@@ -154,8 +161,6 @@ Plack::App::Search - Plack search application.
 
 Constructor.
 
-Returns instance of object.
-
 =over 8
 
 =item * C<css>
@@ -182,6 +187,14 @@ Search method.
 
 Default value is 'search'.
 
+=item * C<search_placeholder>
+
+Search placeholder text.
+
+It's optional.
+
+Default value is undef.
+
 =item * C<search_title>
 
 Search title. There will be button with text in this title if is defined.
@@ -209,6 +222,8 @@ Default value is 'Login page'.
 
 =back
 
+Returns instance of object.
+
 =head2 C<call>
 
  my $psgi_ar = $obj->call($env);
@@ -413,12 +428,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2021-2023 Michal Josef Špaček
+© 2021-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
